EXPORTS
	??1COssCombination@@UAE@XZ @ 1 NONAME ; COssCombination::~COssCombination(void)
	??1COssHangulInputContext@@UAE@XZ @ 2 NONAME ; COssHangulInputContext::~COssHangulInputContext(void)
	??1COssKeyboard@@UAE@XZ @ 3 NONAME ; COssKeyboard::~COssKeyboard(void)
	?AddCombinationL@COssCombination@@QAEHABVTOssCombinationItem@@@Z @ 4 NONAME ; int COssCombination::AddCombinationL(class TOssCombinationItem const &)
	?AddEventObserver@COssHangulInputContext@@QAEXPAVMOssHangulInputEventObserver@@@Z @ 5 NONAME ; void COssHangulInputContext::AddEventObserver(class MOssHangulInputEventObserver *)
	?BackSpace@COssHangulInputContext@@QAEHXZ @ 6 NONAME ; int COssHangulInputContext::BackSpace(void)
	?FindCombination@COssCombination@@QAEHABVTOssCombinationItem@@@Z @ 7 NONAME ; int COssCombination::FindCombination(class TOssCombinationItem const &)
	?Flush@COssHangulInputContext@@QAE?AVTPtrC16@@XZ @ 8 NONAME ; class TPtrC16 COssHangulInputContext::Flush(void)
	?GetCommitString@COssHangulInputContext@@QAE?AVTPtrC16@@XZ @ 9 NONAME ; class TPtrC16 COssHangulInputContext::GetCommitString(void)
	?GetPreeditString@COssHangulInputContext@@QAE?AVTPtrC16@@XZ @ 10 NONAME ; class TPtrC16 COssHangulInputContext::GetPreeditString(void)
	?HasChoseong@COssHangulInputContext@@QAEHXZ @ 11 NONAME ; int COssHangulInputContext::HasChoseong(void)
	?HasJongseong@COssHangulInputContext@@QAEHXZ @ 12 NONAME ; int COssHangulInputContext::HasJongseong(void)
	?HasJungseong@COssHangulInputContext@@QAEHXZ @ 13 NONAME ; int COssHangulInputContext::HasJungseong(void)
	?IsEmpty@COssHangulInputContext@@QAEHXZ @ 14 NONAME ; int COssHangulInputContext::IsEmpty(void)
	?NewL@COssCombination@@SAPAV1@XZ @ 15 NONAME ; class COssCombination * COssCombination::NewL(void)
	?NewL@COssHangulInputContext@@SAPAV1@ABVTDesC8@@@Z @ 16 NONAME ; class COssHangulInputContext * COssHangulInputContext::NewL(class TDesC8 const &)
	?NewL@COssKeyboard@@SAPAV1@XZ @ 17 NONAME ; class COssKeyboard * COssKeyboard::NewL(void)
	?NewLC@COssCombination@@SAPAV1@XZ @ 18 NONAME ; class COssCombination * COssCombination::NewLC(void)
	?NewLC@COssHangulInputContext@@SAPAV1@ABVTDesC8@@@Z @ 19 NONAME ; class COssHangulInputContext * COssHangulInputContext::NewLC(class TDesC8 const &)
	?NewLC@COssKeyboard@@SAPAV1@XZ @ 20 NONAME ; class COssKeyboard * COssKeyboard::NewLC(void)
	?Process@COssHangulInputContext@@QAEHABVTChar@@@Z @ 21 NONAME ; int COssHangulInputContext::Process(class TChar const &)
	?RemoveCombination@COssCombination@@QAEHABVTOssCombinationItem@@@Z @ 22 NONAME ; int COssCombination::RemoveCombination(class TOssCombinationItem const &)
	?RemoveEventObserver@COssHangulInputContext@@QAEXPAVMOssHangulInputEventObserver@@@Z @ 23 NONAME ; void COssHangulInputContext::RemoveEventObserver(class MOssHangulInputEventObserver *)
	?Reset@COssHangulInputContext@@QAEXXZ @ 24 NONAME ; void COssHangulInputContext::Reset(void)
	?SelectKeyboard@COssHangulInputContext@@QAEXABVTDesC8@@@Z @ 25 NONAME ; void COssHangulInputContext::SelectKeyboard(class TDesC8 const &)
	?SetCombinationL@COssHangulInputContext@@QAEXAAVCOssCombination@@@Z @ 26 NONAME ; void COssHangulInputContext::SetCombinationL(class COssCombination &)
	?SetKeyboard@COssHangulInputContext@@QAEXABVCOssKeyboard@@@Z @ 27 NONAME ; void COssHangulInputContext::SetKeyboard(class COssKeyboard const &)
	?SetOutputMode@COssHangulInputContext@@QAEXABH@Z @ 28 NONAME ; void COssHangulInputContext::SetOutputMode(int const &)
	?SetType@COssKeyboard@@QAEXABH@Z @ 29 NONAME ; void COssKeyboard::SetType(int const &)
	?SetValue@COssKeyboard@@QAEXABHABVTChar@@@Z @ 30 NONAME ; void COssKeyboard::SetValue(int const &, class TChar const &)

